masamune_test library

This package is designed to test the Masamune framework.

To use, import package:masamune_ai/masamune_ai.dart.

Classes

MasamuneControllerTest
Controller test items.
MasamuneTestConfig
The configuration of the Masamune Test.
MasamuneTestContainer
Wrapper for testing widgets (primarily screens) with device constraints.
MasamuneTestDevice
Device settings for Masamune Test.
MasamuneTestLoader<T>
Wrapper for testing widgets (primarily screens) with device constraints.
MasamuneTestRef
Masamune Test References.

Functions

masamuneControllerTest({required String name, required List<MasamuneControllerTest> tests}) → void
Perform controller testing.
masamuneModelTileTest<T extends ModelRefBase>({required String name, required String path, required T document(BuildContext context, MasamuneTestRef ref), required Widget builder(BuildContext context, MasamuneTestRef ref, T value), List<ImageProvider<Object>>? preCacheImages}) → void
Tests the toTile extension of the Model.
masamunePageTest<T>({required String name, required String path, required Widget builder(BuildContext context, MasamuneTestRef ref, T? value), FutureOr<T?> loader(BuildContext context, MasamuneTestRef ref)?, List<ImageProvider<Object>>? preCacheImages, List<MasamuneTestDevice>? devices}) → void
Tests a page.
masamuneWidgetTest<T>({required String name, required String path, required Widget builder(BuildContext context, MasamuneTestRef ref, T? value), FutureOr<T?> loader(BuildContext context, MasamuneTestRef ref)?, List<ImageProvider<Object>>? preCacheImages, double width = 640, double? height}) → void
Tests a widget.