masamuneControllerTest function

  1. @isTest
void masamuneControllerTest({
  1. required String name,
  2. required List<MasamuneControllerTest> tests,
})

Perform controller testing.

Pass the test name to name, and perform the controller test you want to test on tests.

コントローラのテストを行います。

nameにテスト名を渡し、testsにテストをしたいコントローラのテストを行います。

Implementation

@isTest
void masamuneControllerTest({
  required String name,
  required List<MasamuneControllerTest> tests,
}) {
  for (final t in tests) {
    test(
      "$name - ${t.name.toPascalCase()}",
      () {
        return t.run(MasamuneTestConfig.currentRef);
      },
    );
  }
}