MasamuneTestConfig class
The configuration of the Masamune Test.
Masamune Testの設定。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- currentRef → MasamuneTestRef
-
The current reference of the Masamune Test.
no setter
-
defaultDevices
↔ List<
MasamuneTestDevice> -
The default devices of the Masamune Test.
getter/setter pair
Static Methods
-
initialize(
{required FutureOr< void> run(), bool enablePlatformGoldensConfig = true, ScopedValueContainer? scopedValueContainer, String? initialUserId, AuthAdapter? authAdapter, StorageAdapter? storageAdapter, FunctionsAdapter? functionsAdapter, PlatformInfoAdapter? platformInfoAdapter, List<LoggerAdapter> loggerAdapters = const [], ModelAdapter? modelAdapter, DateTime? testCurrentTime, AppThemeData? theme, List<MasamuneAdapter> masamuneAdapters = const [], List<LocalizationsDelegate> ? localizationsDelegates, FutureOr<String> ciFilePathResolver(String fileName, String environmentName)?, FutureOr<String> platformFilePathResolver(String fileName, String environmentName)?, List<MasamuneTestDevice> defaultDevices = const [MasamuneTestDevice.phonePortrait, MasamuneTestDevice.phoneLandscape, MasamuneTestDevice.tabletPortrait, MasamuneTestDevice.tabletLandscape]}) → Future<void> - Initialize the Masamune Test.