MasamuneTestDevice class
Device settings for Masamune Test.
Masamune Testのデバイス設定。
Constructors
- MasamuneTestDevice({required Size size, required String name, double devicePixelRatio = 1.0, double textScaleFactor = 1.0, Brightness brightness = Brightness.light, EdgeInsets safeArea = const EdgeInsets.all(0)})
-
Device settings for Masamune Test.
const
Properties
- brightness → Brightness
-
brightness specify platform brightness.
final
- devicePixelRatio → double
-
devicePixelRatio specify device Pixel Ratio.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
name specify device name. Ex: Phone, Tablet, Watch.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safeArea → EdgeInsets
-
safeArea specify insets to define a safe area.
final
- size → Size
-
size specify device screen size. Ex: Size(1366, 1024)).
final
- textScaleFactor → double
-
textScaleFactor specify custom text scale factor.
final
Methods
-
copyWith(
{Size? size, double? devicePixelRatio, String? name, double? textScale, Brightness? brightness, EdgeInsets? safeArea}) → MasamuneTestDevice - copyWith convenience function for MasamuneTestDevice modification.
-
dark(
) → MasamuneTestDevice - dark convenience method to copy the current device and apply dark theme.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- phoneLandscape → const MasamuneTestDevice
- phoneLandscape matches specs of iphone16, but in landscape mode.
- phonePortrait → const MasamuneTestDevice
- phonePortrait matches specs of iphone16, but with lower DPI for performance.
- tabletLandscape → const MasamuneTestDevice
- tabletLandscape example of tablet that in landscape mode.
- tabletPortrait → const MasamuneTestDevice
- tabletPortrait example of tablet that in portrait mode.